Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: include/dart_api.h

Issue 10433003: Make Dart_GetClass work for private classes. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/dart_api.h
===================================================================
--- include/dart_api.h (revision 7924)
+++ include/dart_api.h (working copy)
@@ -2036,12 +2036,16 @@
DART_EXPORT bool Dart_IsLibrary(Dart_Handle object);
/**
- * Lookup a class by name from a Library.
+ * Lookup a class or interface by name from a Library.
*
* \return If no error occurs, the Library is returned. Otherwise an
* error handle is returned.
*/
-DART_EXPORT Dart_Handle Dart_GetClass(Dart_Handle library, Dart_Handle name);
+DART_EXPORT Dart_Handle Dart_GetClass(Dart_Handle library,
+ Dart_Handle class_name);
// TODO(turnidge): Consider returning Dart_Null() when the class is
// not found to distinguish that from a true error case.
« no previous file with comments | « no previous file | vm/dart_api_impl.cc » ('j') | no next file with comments »
@@ -2036,12 +2036,16 @@
*
- * \return If no error occurs, the Library is returned. Otherwise an
- * error handle is returned.
+ * \param library The library containing the class or interface.
+ * \param class_name The name of the class or interface.
+ *
+ * \return If no error occurs, the class or interface is
+ * returned. Otherwise an error handle is returned.
*/

Powered by Google App Engine
This is Rietveld 408576698